# Forwarder Template ROM Source - Based on Forwarder-Mod of nx-hbloader
Host process for loading Switch homebrew NROs. This mod allows to create NROs/Retroarch Forwarders.

# Use
Compile this sub dir using devkitpro, it will generate hbl.nso (main)  and hbl.npdm (main.npdm) binary files.

The results of the compilation are used as the template file for all NSP's generated by nton.

These only need recompiled when there is a major ABI change, like in 21.x.

# Notes
This template ROM is based on nx-hbloader, with patches applied to allow forwarding to any NRO.

Sources:

https://github.com/switchbrew/nx-hbloader
https://github.com/Skywalker25/Forwarder-Mod

# Changelog
2026-01-17 Applied Forwarder-Mod to latest nx-hbloader, recompiled against latest libnx via devkitpro

# credits
nx-hbloader from switchbrew
nx-hbloader-retroarch-forwarder-mod from natinusala
Forwarder-Mod from Skywalker25
